import { FC, ReactNode, useEffect, useMemo, useRef, useState } from 'react'
import { ShoppingContext } from '../../context'
import { ColorMeta, ColorStore, ShoppingContextValue } from '../../context'

export interface ShoppingCartPropsType {
  initialValues?: ColorStore
  onTriggerCheckbox?: (options: { colorStore: ColorStore; changedCheckbox: ColorMeta }) => void
  children?: ReactNode
}

export const ShoppingCart: FC<ShoppingCartPropsType> = (props) => {
  const { children, onTriggerCheckbox, initialValues } = props

  const onTriggerCheckboxRef = useRef(onTriggerCheckbox)
  onTriggerCheckboxRef.current = onTriggerCheckbox

  const [colorStore, setColorStore] = useState<ColorStore>(() => initialValues || {})
  const [changedCheckbox, setChangedCheckbox] = useState<ColorMeta>({})

  const ctx: ShoppingContextValue = useMemo(() => {
    return {
      colorStore,
      setChangedCheckbox() {},
    }
  }, [colorStore])

  useEffect(() => {
    onTriggerCheckboxRef.current?.({
      colorStore,
      changedCheckbox,
    })

  }, [colorStore, changedCheckbox])
  

  return <ShoppingContext.Provider value={ctx}>{children}</ShoppingContext.Provider>
}
